Renderers
=========

What is it?
-----------

A renderer converts your icon definition to HTML.

This package includes the default renderer `IconRenderer` which renders to an HTML element styled with CSS classes and other attributes, a method used by many icon libraries.

You can use a customized renderer to support specific icon libraries or specific code.

This package includes renderers for FontAwesome 4, Bootstrap 3, Material Design and image sets.

The example app includes a custom SVG renderer.

.. automodule:: django_icons.renderers
